@@ -3,6 +3,7 @@ package Event::idle;
 use Carp;
 use base 'Event::Watcher';
 use vars qw($DefaultPriority);
+use Event qw(%KEY_REMAP);
 
 'Event::Watcher'->register;
 
@@ -11,12 +12,9 @@ sub new {
 
     shift if @_ & 1;
     my %arg = @_;
-
     my $o = allocate();
-    $o->init([qw(min_interval max_interval hard)], \%arg);
-    $o->{repeat} = 1 if (!exists $arg{repeat} and
-			 (defined $o->{min_interval} or
-			  defined $o->{max_interval}));
+    $o->{e_repeat} = 1 if (defined $o->{e_min} or defined $o->{e_max});
+    $o->init(\%arg);
     $o->start;
     $o;
 }
